==> tecfy_corev2_package-1.1.84.tar.gz: lib/main.dart <==
///Committed Main

part of tecfy_corev2_client_package;

// ignore: must_be_immutable
class TecfyCoreApp extends StatelessWidget {
  /// used to redirect to must upgrade page
  static bool mustUpgrade = false;

  /// current version number
  static String get currentVersion => TecfyBasicApp.appVersion;

  static set currentVersion(String v) => TecfyBasicApp.appVersion = v;

  /// API rul
  static set apiURL(v) => ConfigService.apiURL = v;

  /// API URL
  static set wsURL(v) => ConfigService.wsURL = v;

  /// entities service
  static Map<String, IEntityTransaction> entityServices =
      Map<String, IEntityTransaction>();

  /// entities action service
  static Map<String, IEntityAction> entityActionsServices =
      Map<String, IEntityAction>();

  /// theme config
  static set themeConfig(IThemeConfig v) => TecfyBasicApp.themeConfig = v;

  /// theme config
  static IThemeConfig get themeConfig => TecfyBasicApp.themeConfig;

  /// app logo
  static Image? logo;

  /// image
  static late Image backgoundImage;

  /// translate service for multi language
  static ITranslateService? translateService;

  /// init services can be impelemented by host application
  static IInitInterface? initService;

  /// report service
  static IReportService? reportService;

  /// navigate to main page after login
  static FutureOr Function(BuildContext) navigateToDefaultPage = (c) =>
      AppNavigator.navigateToNamed(c, '/',
          replaceAll: true, animationType: AnimationTypes.opacity);

  /// navigate to signup page
  static FutureOr Function(BuildContext)? navigateToSignupPage;

  /// update local db function
  /// this function called after login
  // static Future Function(Database, int, int) updateSqlLiteDb =
  //     (d, f, t) async {};

  /// db version
  static int appDbVersion = 0;

  /// menu service
  static IMenuInterface? menuService;

  /// package info
  // static late PackageInfo packageInfo;

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    // kReleaseMode;
    //   if (kReleaseMode) {
    return StreamBuilder<Language>(
        stream: AppLocale.languageStream,
        initialData: LocalConfigService.language,
        builder: (context, languageSnapshot) {
          AppLocale.appLocale = null;
          return _getApp(languageSnapshot.data ?? Language.arabic, context);
        });
    // } else {
    //   return _getApp(LocalConfigService.language);
    // }
  }

  dynamic timeout = Duration(seconds: ConfigService.getValueInt('LockTimeout'));
  dynamic ms = const Duration(milliseconds: 1);
  Timer? timer;

  startTimeout(context, [int? milliseconds]) {
    if (ConfigService.getValueInt('LockTimeout') != 0) {
      var duration = milliseconds == null ? timeout : ms * milliseconds;
      return Timer(duration, () async {
        print(duration);
        await ConfigService.setValueBool('LoginExpired', true);
        TecfyBasicApp.appGlobalkey.currentState!
            .pushNamedAndRemoveUntil('/login', (route) => false);
      });
    } else {
      return null;
    }
  }

  _getApp(Language language, context) {
    if (timer != null) timer!.cancel();
    if (ConfigService.getValueInt('LockTimeout') == 0) {
      return MaterialApp(
        key: kReleaseMode ? UniqueKey() : null,
        title: 'Application',
        navigatorKey: TecfyBasicApp.appGlobalkey,
        builder: BotToastInit(),
        scrollBehavior: AppScrollBehavior(),
        theme: ThemeService.getMainThemeAndroid(),
        supportedLocales: [const Locale('ar', 'SA'), const Locale('en', 'US')],
        localizationsDelegates: [
          const AppLocalizationsDelegate(),
          GlobalCupertinoLocalizations.delegate,
          DefaultCupertinoLocalizations.delegate,
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          DefaultCupertinoLocalizations.delegate
        ],
        locale: language == Language.arabic
            ? const Locale('ar', 'SA')
            : const Locale('en', 'US'),
        localeResolutionCallback:
            (Locale? deviceLocale, Iterable<Locale> supportedLocales) {
          ConfigService.isRTL = (language == Language.arabic);
          var selectedLanguageCode =
              (language == Language.arabic) ? 'ar' : 'en';
          var lcl = supportedLocales
              .firstWhere((d) => d.languageCode == selectedLanguageCode);

          return lcl;
        },
        //home: SplashScreenPage(),
        onGenerateRoute: (RouteSettings settings) {
          if (kDebugMode) print('Route:${settings.name}');
          if (mustUpgrade)
            return GeneratePageRoute(
                widget: UpgradePage(isRequired: true), routeName: '/upgrade');

          if (!InitService.isInitled)
            return GeneratePageRoute(
                widget: SplashScreenPage(), routeName: settings.name ?? '');

          switch (settings.name) {
            case '/':
              return GeneratePageRoute(
                  widget: DashboardPage(), routeName: settings.name ?? '');
            case '/loading':
              return GeneratePageRoute(
                  widget: SplashScreenPage(), routeName: settings.name ?? '');
            case '/login':
              return GeneratePageRoute(
                  widget: LoginPage(), routeName: settings.name ?? '');
            case '/setting':
              return GeneratePageRoute(
                  widget: SettingPage(false), routeName: settings.name ?? '');
            case '/upgrade':
              return GeneratePageRoute(
                  widget: UpgradePage(), routeName: settings.name ?? '');
            default:
              return GeneratePageRoute(
                  widget: DashboardPage(), routeName: settings.name ?? '');
          }
        },
        initialRoute: mustUpgrade ? '/upgrade' : '/loading',
      );
    } else {
      return Listener(
          behavior: HitTestBehavior.translucent,
          onPointerUp: (PointerUpEvent pointer) {
            print(pointer.kind.name);
            if (timer != null) {
              timer!.cancel();
            }
            timer = startTimeout(context);
          },
          child: MaterialApp(
            key: kReleaseMode ? UniqueKey() : null,
            title: 'Application',
            navigatorKey: TecfyBasicApp.appGlobalkey,
            builder: BotToastInit(),
            scrollBehavior: AppScrollBehavior(),
            theme: ThemeService.getMainThemeAndroid(),
            supportedLocales: [
              const Locale('ar', 'SA'),
              const Locale('en', 'US')
            ],
            localizationsDelegates: [
              const AppLocalizationsDelegate(),
              GlobalCupertinoLocalizations.delegate,
              DefaultCupertinoLocalizations.delegate,
              GlobalMaterialLocalizations.delegate,
              GlobalWidgetsLocalizations.delegate,
              DefaultCupertinoLocalizations.delegate
            ],
            locale: language == Language.arabic
                ? const Locale('ar', 'SA')
                : const Locale('en', 'US'),
            localeResolutionCallback:
                (Locale? deviceLocale, Iterable<Locale> supportedLocales) {
              ConfigService.isRTL = (language == Language.arabic);
              var selectedLanguageCode =
                  (language == Language.arabic) ? 'ar' : 'en';
              var lcl = supportedLocales
                  .firstWhere((d) => d.languageCode == selectedLanguageCode);

              return lcl;
            },
            //home: SplashScreenPage(),
            onGenerateRoute: (RouteSettings settings) {
              if (kDebugMode) print('Route:${settings.name}');
              if (mustUpgrade)
                return GeneratePageRoute(
                    widget: UpgradePage(isRequired: true),
                    routeName: '/upgrade');

              if (!InitService.isInitled)
                return GeneratePageRoute(
                    widget: SplashScreenPage(), routeName: settings.name ?? '');

              switch (settings.name) {
                case '/':
                  return GeneratePageRoute(
                      widget: DashboardPage(), routeName: settings.name ?? '');
                case '/loading':
                  return GeneratePageRoute(
                      widget: SplashScreenPage(),
                      routeName: settings.name ?? '');
                case '/login':
                  return GeneratePageRoute(
                      widget: LoginPage(), routeName: settings.name ?? '');
                case '/setting':
                  return GeneratePageRoute(
                      widget: SettingPage(false),
                      routeName: settings.name ?? '');
                case '/upgrade':
                  return GeneratePageRoute(
                      widget: UpgradePage(), routeName: settings.name ?? '');
                default:
                  return GeneratePageRoute(
                      widget: DashboardPage(), routeName: settings.name ?? '');
              }
            },
            initialRoute: mustUpgrade ? '/upgrade' : '/loading',
          ));
    }
  }

  /// init application
  static void init({String? mapAPI}) {
    if (mapAPI != null) {
      //GoogleMap.init(mapAPI);
    }
    IApiService.unauthrizedCallback = (response) {
      print('unauthrizedCallback');
      Future.delayed(Duration(milliseconds: 10)).then((v) {
        AccountService.loginExpired(TecfyBasicApp.appGlobalkey.currentContext);
      });
    };
  }
}

class AppScrollBehavior extends MaterialScrollBehavior {
  // Override behavior methods and getters like dragDevices
  @override
  Set<PointerDeviceKind> get dragDevices => {
        PointerDeviceKind.touch,
        PointerDeviceKind.mouse,
      };
}

class GeneratePageRoute extends PageRouteBuilder {
  /// widget
  final Widget widget;

  /// route name for url navigator
  final String routeName;

  /// rounting widget to restart the app after language changes
  GeneratePageRoute({required this.widget, required this.routeName})
      : super(
          settings: RouteSettings(name: routeName),
          pageBuilder: (BuildContext context, Animation<double> animation,
              Animation<double> secondaryAnimation) {
            return widget;
          },
        );
}

==> tecfy_corev2_package-1.1.91.tar.gz: lib/main.dart <==
///Committed Main

part of tecfy_corev2_client_package;

// ignore: must_be_immutable
class TecfyCoreApp extends StatelessWidget {
  /// used to redirect to must upgrade page
  static bool mustUpgrade = false;

  /// current version number
  static String get currentVersion => TecfyBasicApp.appVersion;

  static set currentVersion(String v) => TecfyBasicApp.appVersion = v;

  /// API rul
  static set apiURL(v) => ConfigService.apiURL = v;

  /// API URL
  static set wsURL(v) => ConfigService.wsURL = v;

  /// entities service
  static Map<String, IEntityTransaction> entityServices =
      Map<String, IEntityTransaction>();

  /// entities action service
  static Map<String, IEntityAction> entityActionsServices =
      Map<String, IEntityAction>();

  /// theme config
  static set themeConfig(IThemeConfig v) => TecfyBasicApp.themeConfig = v;

  /// theme config
  static IThemeConfig get themeConfig => TecfyBasicApp.themeConfig;

  /// app logo
  static Image? logo;

  /// image
  static late Image backgoundImage;

  /// translate service for multi language
  static ITranslateService? translateService;

  /// init services can be impelemented by host application
  static IInitInterface? initService;

  /// report service
  static IReportService? reportService;

  /// navigate to main page after login
  static FutureOr Function(BuildContext) navigateToDefaultPage = (c) =>
      AppNavigator.navigateToNamed(c, '/',
          replaceAll: true, animationType: AnimationTypes.opacity);

  /// navigate to signup page
  static FutureOr Function(BuildContext)? navigateToSignupPage;

  /// update local db function
  /// this function called after login
  // static Future Function(Database, int, int) updateSqlLiteDb =
  //     (d, f, t) async {};

  /// db version
  static int appDbVersion = 0;

  /// menu service
  static IMenuInterface? menuService;

  /// package info
  // static late PackageInfo packageInfo;

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    // kReleaseMode;
    //   if (kReleaseMode) {
    return StreamBuilder<Language>(
        stream: AppLocale.languageStream,
        initialData: LocalConfigService.language,
        builder: (context, languageSnapshot) {
          AppLocale.appLocale = null;
          return _getApp(languageSnapshot.data ?? Language.arabic, context);
        });
    // } else {
    //   return _getApp(LocalConfigService.language);
    // }
  }

  dynamic timeout = Duration(seconds: ConfigService.getValueInt('LockTimeout'));
  dynamic ms = const Duration(milliseconds: 1);
  Timer? timer;

  startTimeout(context, [int? milliseconds]) {
    if (ConfigService.getValueInt('LockTimeout') != 0) {
      var duration = milliseconds == null ? timeout : ms * milliseconds;
      return Timer(duration, () async {
        print(duration);
        await ConfigService.setValueBool('LoginExpired', true);
        TecfyBasicApp.appGlobalkey.currentState!
            .pushNamedAndRemoveUntil('/login', (route) => false);
      });
    } else {
      return null;
    }
  }

  _getApp(Language language, context) {
    if (timer != null) timer!.cancel();
    if (ConfigService.getValueInt('LockTimeout') == 0) {
      return MaterialApp(
        key: kReleaseMode ? UniqueKey() : null,
        title: 'Application',
        navigatorKey: TecfyBasicApp.appGlobalkey,
        builder: BotToastInit(),
        scrollBehavior: AppScrollBehavior(),
        theme: ThemeService.getMainThemeAndroid().copyWith(useMaterial3: false),
        supportedLocales: [const Locale('ar', 'SA'), const Locale('en', 'US')],
        localizationsDelegates: [
          const AppLocalizationsDelegate(),
          GlobalCupertinoLocalizations.delegate,
          DefaultCupertinoLocalizations.delegate,
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          DefaultCupertinoLocalizations.delegate
        ],
        locale: language == Language.arabic
            ? const Locale('ar', 'SA')
            : const Locale('en', 'US'),
        localeResolutionCallback:
            (Locale? deviceLocale, Iterable<Locale> supportedLocales) {
          ConfigService.isRTL = (language == Language.arabic);
          var selectedLanguageCode =
              (language == Language.arabic) ? 'ar' : 'en';
          var lcl = supportedLocales
              .firstWhere((d) => d.languageCode == selectedLanguageCode);

          return lcl;
        },
        //home: SplashScreenPage(),
        onGenerateRoute: (RouteSettings settings) {
          if (kDebugMode) print('Route:${settings.name}');
          if (mustUpgrade)
            return GeneratePageRoute(
                widget: UpgradePage(isRequired: true), routeName: '/upgrade');

          if (!InitService.isInitled)
            return GeneratePageRoute(
                widget: SplashScreenPage(), routeName: settings.name ?? '');

          switch (settings.name) {
            case '/':
              return GeneratePageRoute(
                  widget: DashboardPage(), routeName: settings.name ?? '');
            case '/loading':
              return GeneratePageRoute(
                  widget: SplashScreenPage(), routeName: settings.name ?? '');
            case '/login':
              return GeneratePageRoute(
                  widget: LoginPage(), routeName: settings.name ?? '');
            case '/setting':
              return GeneratePageRoute(
                  widget: SettingPage(false), routeName: settings.name ?? '');
            case '/upgrade':
              return GeneratePageRoute(
                  widget: UpgradePage(), routeName: settings.name ?? '');
            default:
              return GeneratePageRoute(
                  widget: DashboardPage(), routeName: settings.name ?? '');
          }
        },
        initialRoute: mustUpgrade ? '/upgrade' : '/loading',
      );
    } else {
      return Listener(
          behavior: HitTestBehavior.translucent,
          onPointerUp: (PointerUpEvent pointer) {
            print(pointer.kind.name);
            if (timer != null) {
              timer!.cancel();
            }
            timer = startTimeout(context);
          },
          child: MaterialApp(
            key: kReleaseMode ? UniqueKey() : null,
            title: 'Application',
            navigatorKey: TecfyBasicApp.appGlobalkey,
            builder: BotToastInit(),
            scrollBehavior: AppScrollBehavior(),
            theme: ThemeService.getMainThemeAndroid().copyWith(useMaterial3: false),
            supportedLocales: [
              const Locale('ar', 'SA'),
              const Locale('en', 'US')
            ],
            localizationsDelegates: [
              const AppLocalizationsDelegate(),
              GlobalCupertinoLocalizations.delegate,
              DefaultCupertinoLocalizations.delegate,
              GlobalMaterialLocalizations.delegate,
              GlobalWidgetsLocalizations.delegate,
              DefaultCupertinoLocalizations.delegate
            ],
            locale: language == Language.arabic
                ? const Locale('ar', 'SA')
                : const Locale('en', 'US'),
            localeResolutionCallback:
                (Locale? deviceLocale, Iterable<Locale> supportedLocales) {
              ConfigService.isRTL = (language == Language.arabic);
              var selectedLanguageCode =
                  (language == Language.arabic) ? 'ar' : 'en';
              var lcl = supportedLocales
                  .firstWhere((d) => d.languageCode == selectedLanguageCode);

              return lcl;
            },
            //home: SplashScreenPage(),
            onGenerateRoute: (RouteSettings settings) {
              if (kDebugMode) print('Route:${settings.name}');
              if (mustUpgrade)
                return GeneratePageRoute(
                    widget: UpgradePage(isRequired: true),
                    routeName: '/upgrade');

              if (!InitService.isInitled)
                return GeneratePageRoute(
                    widget: SplashScreenPage(), routeName: settings.name ?? '');

              switch (settings.name) {
                case '/':
                  return GeneratePageRoute(
                      widget: DashboardPage(), routeName: settings.name ?? '');
                case '/loading':
                  return GeneratePageRoute(
                      widget: SplashScreenPage(),
                      routeName: settings.name ?? '');
                case '/login':
                  return GeneratePageRoute(
                      widget: LoginPage(), routeName: settings.name ?? '');
                case '/setting':
                  return GeneratePageRoute(
                      widget: SettingPage(false),
                      routeName: settings.name ?? '');
                case '/upgrade':
                  return GeneratePageRoute(
                      widget: UpgradePage(), routeName: settings.name ?? '');
                default:
                  return GeneratePageRoute(
                      widget: DashboardPage(), routeName: settings.name ?? '');
              }
            },
            initialRoute: mustUpgrade ? '/upgrade' : '/loading',
          ));
    }
  }

  /// init application
  static void init({String? mapAPI}) {
    if (mapAPI != null) {
      //GoogleMap.init(mapAPI);
    }
    IApiService.unauthrizedCallback = (response) {
      print('unauthrizedCallback');
      Future.delayed(Duration(milliseconds: 10)).then((v) {
        AccountService.loginExpired(TecfyBasicApp.appGlobalkey.currentContext);
      });
    };
  }
}

class AppScrollBehavior extends MaterialScrollBehavior {
  // Override behavior methods and getters like dragDevices
  @override
  Set<PointerDeviceKind> get dragDevices => {
        PointerDeviceKind.touch,
        PointerDeviceKind.mouse,
      };
}

class GeneratePageRoute extends PageRouteBuilder {
  /// widget
  final Widget widget;

  /// route name for url navigator
  final String routeName;

  /// rounting widget to restart the app after language changes
  GeneratePageRoute({required this.widget, required this.routeName})
      : super(
          settings: RouteSettings(name: routeName),
          pageBuilder: (BuildContext context, Animation<double> animation,
              Animation<double> secondaryAnimation) {
            return widget;
          },
        );
}
